﻿# ##########################################################################
# Programme Python permettant de calculer la norme de la vitesse et les énergies
# potentielles, cinétiques, mécaniques à partir d'un pointage.

# à destination des élèves qui peuvent modifier le code sous les parties roses

# Le code est volontairement simplifié pour qu'un élève puisse se
# l'approprier et surtout "coder"

# X,Y et t sont importés dans des listes Numpy

# L'auteur a fait le choix de calculer Vx, Vyx et V
# mais il est possible de le faire faire aux élèves
# ##########################################################################
# O. CHAUMETTE - Lycée JP SARTRE - 69500 BRON - olivier.chaumette@ac-lyon.fr
# ##########################################################################
# version 2 - mars 2019

# ##########################
# IMPORTATION DES MODULES #
# #########################
# importation de NUMPY (pour gestion tableaux et calculs) sous l'alias "np"
import numpy as np
# importation de PYPLOT (du module MATPLOTLIB, pour le tracé de courbes) sous l'alias "plt"
import matplotlib.pyplot as plt

# modules permettant d'importer des données
# le fichier "import_donnees_meca.py" est indispensable
from import_donnees_meca import traiteDonnees


# Initialisation des tableaux numpy contenant x,y,t , la norme de V et ses coordonées
x=np.array([])
y=np.array([])
t=np.array([])
V=np.array([])
Vx=np.array([])
Vy=np.array([])


""" ---------------------------------
        CHOIX du PROFESSEUR
------------------------------------- """
#  Logiciel utilisé à choisir parmi :
# 'pymecavideo'     (exporter un fichier TXT)
# 'latispro'        (fichier TXT créé par LATISPRO, avec décimale VIRGULE et séparation POINT VIRGULE)
# 'avimeca'         (crééer un fichier TXT en export)
# 'avistep'         (pointage exporté depuis AVISTEP:
# 'equation'        (équation paramétrées saisies dans le fichier "import_donnees")
# 'entrees'        (données de pointage saisies "à la main" dans le fichier "import_donnees.py)

Logiciel_Utilise = 'latispro'

""" ---------------------------------
        FIN du CHOIX du PROFESSEUR
------------------------------------- """

t, x, y = traiteDonnees(Logiciel_Utilise)
Nbre_Mesures=len(x)

# ################################
# Calcul de la vitesse
# ################################
# cette partie peut être traitée éventuellement par les élèves
# on parcourt toutes les mesures (de la 2ème à l'avant-dernière) pour calculer Vx et Vy
# d'où ce "1" et "Nbre_Mesures-1"     (rappel: 1ère mesure = index 0)
for n in range(1,Nbre_Mesures-1):
    # pour chaque mesure n, on ajoute au tableau Vx la coordonnée de V suivant X
    Vx=np.append(Vx,(x[n+1]-x[n-1])/(t[n+1]-t[n-1]))
    Vy=np.append(Vy,(y[n+1]-y[n-1])/(t[n+1]-t[n-1]))
    # On créée le tableau V, norme de la vitesse
    V=np.sqrt(Vx**2+Vy**2)

# ################################
# Modification des listes y et t pour que le nombre de points soit le même que V
# ################################
# ATTENTION ! le tableau V contiendra 2 éléments de moins que x, y ou t
# car, pour calculer V, on utilise le point d'avant et celui d'après
# donc pas de vitesse en 0 et au tout dernier t.
# Afin de pouvoir ajouter des tableaux entre eux, il faut qu'ils aient le même
# nombre d'élements. Il faut donc, dans y et t (x inutile pour Ep),
# enlever le dernier élement et le 1er

# sauvegarde des listes y et t avant de les modifier (toujours utile...)
sauv_y=y
sauv_t=t
# on enlève le dernier élément de y et t
y=np.delete(y,len(y)-1)
t=np.delete(t,len(t)-1)
# et le premier:
y=np.delete(y,0)
t=np.delete(t,0)


""" ###########################################
Ici commence le travail à réaliser par les élèves
################################################# """
# ################################
# Initialisation des variables pour l'exercice
# ################################
""" TRAVAIL 1:  masse et accélération de la pesanteur
 Rentrer ci-dessous les valeurs de m et g dans les unités du système international"""
m= 0.200
g=9.81

# #####################################
# Calculs des énergies
# #####################################
""" TRAVAIL 2:
Taper ci-dessous le code Python permettant de calculer les valeurs d'Ec, Ep et Em à chaque date.
Grandeurs disponibles:
    - t  : date
    - x  : l'abscisse du système à la date t
    - y  : l'ordonnée donc l'altitude du système à t
    - V  : norme du vecteur vitesse à la date t"""
Ec=0.5*m*V*V
Ep = m*g*y
Em=Ec+Ep


# #####################################
# Tracé
# #####################################
""" TRAVAIL 3:
code Python permettant de tracer Ec, Ep et Em en fonction de la date"""
plt.plot(t,Ec,'xr', label="Energie cinétique")
plt.plot(t,Ep,'xb', label="Energie potentielle")
plt.plot(t,Em,'xk', label="Energie mécanique")

""" TRAVAIL 4:
taper, à la place des points entre guillemets, les légendes pour les axes,
le titre du graphique et mettre un commentaire
pour chaque courbe de la même couleur
à des coordonnées intéressantes"""
plt.title("Variation de l'énergie en fonction du temps")
plt.xlabel("date t (s)")
plt.ylabel("Energie (J)")
""" fin du travail """


# On affiche une grille
plt.grid()
# On affiche le commentaire
plt.legend(bbox_to_anchor=(1.05, 1),loc='upper left',borderaxespad=0.)
# affichage de la figure bien adapté à la fenêtre la fenêtre
plt.tight_layout()
# on affiche la fenêtre
#plt.get_current_fig_manager().window.state('zoomed')   # <-- Affiche la fenêtre maximisée sous windows uniquement
plt.show()
